package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcContractMeetingMapper;
import com.ruoyi.oa.domain.CmcContractMeeting;
import com.ruoyi.oa.service.ICmcContractMeetingService;

/**
 * cmc合同会审Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-19
 */
@Service
public class CmcContractMeetingServiceImpl implements ICmcContractMeetingService 
{
    @Autowired
    private CmcContractMeetingMapper cmcContractMeetingMapper;

    /**
     * 查询cmc合同会审
     * 
     * @param contractId cmc合同会审主键
     * @return cmc合同会审
     */
    @Override
    public CmcContractMeeting selectCmcContractMeetingByContractId(String contractId)
    {
        return cmcContractMeetingMapper.selectCmcContractMeetingByContractId(contractId);
    }

    /**
     * 查询cmc合同会审列表
     * 
     * @param cmcContractMeeting cmc合同会审
     * @return cmc合同会审
     */
    @Override
    public List<CmcContractMeeting> selectCmcContractMeetingList(CmcContractMeeting cmcContractMeeting)
    {
        return cmcContractMeetingMapper.selectCmcContractMeetingList(cmcContractMeeting);
    }

    /**
     * 新增cmc合同会审
     * 
     * @param cmcContractMeeting cmc合同会审
     * @return 结果
     */
    @Override
    public int insertCmcContractMeeting(CmcContractMeeting cmcContractMeeting)
    {
        return cmcContractMeetingMapper.insertCmcContractMeeting(cmcContractMeeting);
    }

    /**
     * 修改cmc合同会审
     * 
     * @param cmcContractMeeting cmc合同会审
     * @return 结果
     */
    @Override
    public int updateCmcContractMeeting(CmcContractMeeting cmcContractMeeting)
    {
        return cmcContractMeetingMapper.updateCmcContractMeeting(cmcContractMeeting);
    }

    /**
     * 批量删除cmc合同会审
     * 
     * @param contractIds 需要删除的cmc合同会审主键
     * @return 结果
     */
    @Override
    public int deleteCmcContractMeetingByContractIds(String[] contractIds)
    {
        return cmcContractMeetingMapper.deleteCmcContractMeetingByContractIds(contractIds);
    }

    /**
     * 删除cmc合同会审信息
     * 
     * @param contractId cmc合同会审主键
     * @return 结果
     */
    @Override
    public int deleteCmcContractMeetingByContractId(String contractId)
    {
        return cmcContractMeetingMapper.deleteCmcContractMeetingByContractId(contractId);
    }
}
